# UEQ+ Erweiterung - Dashboard

## Table of Contents

* [Description](#description)
* [Project Structure](#project-structure)
* [Roadmap](#roadmap)
* [New Items for the UEQ+ v2](#new-items-for-the-ueq-v2)

## Description

This project is a survey to extend the product classes of the UEQ+
[UEQ+ v2 Handbook](https://ueqplus.ueq-research.org/Material/UEQ+_Handbook_V2.pdf). We cannot find any appropriate
product classes for dashboard or VR applications. In the paper from
[Winter et al., 2017](https://dx.doi.org/10.18420/muc2017-up-0002) is published how the product categories are made. It
is also mentioned that if additional categories are needed, this type of survey can be replicated with the new
categories needed. Therefore, we created a questionnaire with the new categories and some categories from the original
questionnaire to create a comparable intersection between both papers. We also updated the UEQ+ to UEQ+v2, which means
that some items had to be newly created as you can see [here](#new-items-for-the-ueq-v2).

### Dashboard

Dashboard applications could be presented in Info-Web-Sites or Learning Platforms product categories because there are
some aspects to dashboards that allow users to access information or engage in targeted learning. However, there are
other use cases that are not covered by these categories, such as the goal of creating understandable data
visualizations.

In Learning Analytics, dashboards are commonly used to aggregate and display indicators that support stakeholders in the
learning process
[Swendimann et al. 2017](https://doi.org/10.1109/TLT.2016.2599522). A quick scan showed that publications about learning
analytics dashboards with a user experience survey only use the UEQ
[Publication 1](https://doi.org/10.1145/3303772.3303793),
[Publication 2](https://www.jstor.org/stable/10.2307/26921130),
[Publication 3](https://doi.org/10.1145/3375462.337551). This lead to the assumption that there is a need for an own
category in UEQ+.

### VR

## Project Structure

The folder structure is based on
[Good enough practices in scientific computing](https://doi.org/10.1371/journal.pcbi.1005510).

```
| -- data                 # folder for raw (mostly survey) data and questionnaire
| -- doc                  # documentation of the computation and analyzation
| -- results              # results of the survey and visualizations
| -- src                  # possible source code to compute the results
```

## Roadmap

- [x] create questionnaire
- [x] pretest
- [ ] conduct survey
    - [x] start date: 05.07.22
    - [ ] final date
- [ ] upload data
- [ ] analyse data and publish results
- [ ] produce publication

In dieser Umfragen können Sie an Hand von mehreren Produktkategorien bestimmen, wie wichtig Ihnen einzelne Merkmale der
Benutzungsoberfläche sind. Die Umfrage wird ca. 5-10 Minuten in Anspruch nehmen.

Ihre Daten werden anonymisiert gespeichert und zu Forschungszwecken weiter verwendet. Das bedeutet, dass die Resultate
sowohl in Promotionsprojekten als auch für etwaige Publikationen verwendet werden können. Durch die anonymisierte
Speicherung ist es uns unmöglich, im Nachhinein bereits erhobene, personenspezifische Daten zu ändern oder zu löschen.

Durch das Fortsetzen der Umfrage bestätigen Sie, mit dem Datenschutzbedingungen einverstanden zu sein.

Für weitere Fragen und Anmerkungen wenden Sie sich bitte bei an Jan Bernoth (jan.bernoth@uni-potsdam.de).

## New items for the UEQ+ v2

This is just in german, because our questionnaire is in german and the original paper is written in german. Anyways,
some decisions are made to extend the questionnaire to v2:

* New sentences were formed by the explanatory words for each scale. For example, attractiveness is not included into
  the original questionnaire, then we took the introducing sentence from the scale of the
  [UEQ+ v2 Template](https://ueqplus.ueq-research.org/Material/UEQPlus_Templates.zip) "In my opinion, the product is
  generally" and connect it with some positive attributes from the scale like enjoyable, pleasant, friendly.
* The last three attributes, which are mainly related to voice assistance, are not considered because the proposed
  product categories are not equipped with this characteristic.

| Items UEQ+ v2                                     | Im [Paper](https://dl.gi.de/bitstream/handle/20.500.12116/5770/2017_UP_002.pdf?sequence=2&isAllowed=y) | Erklärender Satz                                                                                                |
|---------------------------------------------------|--------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------|
| Attraktivität (Attractiveness)                    | ❌                                                                                                      | Insgesamt empfinde ich das Produkt als angenehm, sympathisch und erfreulich.                                    |
| Effizienz (Efficiency)                            | ✔                                                                                                      |                                                                                                                 |
| Durchschaubarkeit (Perspicuity)                   | ✔                                                                                                      |                                                                                                                 |
| Steuerbarkeit (Dependability)                     | ✔                                                                                                      |                                                                                                                 |
| Stimulation (Stimulation)                         | ✔                                                                                                      |                                                                                                                 |
| Originalität (Novelty)                            | ✔                                                                                                      |                                                                                                                 |
| Vertrauen (Trust)                                 | ✔                                                                                                      |                                                                                                                 |
| Haptik (Haptics)                                  | ❌                                                                                                      | Die Oberfläche des Produkts empfinde ich als stabil und angenehm anzufassen. Die Flächen wirken und rutschfest. |
| Akustik (Acoustics)                               | ❌                                                                                                      | Die beim Betrieb des Produkts entstehenden Geräusche sind leise, sanft und wohlklingend.                        |
| Anpassbarkeit (Adaptability)                      | ✔                                                                                                      |                                                                                                                 |
| Nützlichkeit (Usefulness)                         | ✔                                                                                                      |                                                                                                                 |
| Wertigkeit (Value)                                | ✔                                                                                                      |                                                                                                                 |
| Visuelle Ästhetik (Aesthetics)                    | ❌                                                                                                      | Die visuelle Gestaltung des Produkts empfinde ich als schön, stilvoll und ansprechend.                          |
| Intuitive Bedienung (Intuitive use)               | ✔                                                                                                      |                                                                                                                 |
| Vertrauenswürdigkeit (Trustworthiness of Content) | ❌                                                                                                      | Die Informationen und Daten, die mir das Produkt bereitstellt sind nützlich, glaubwürdig und seriös.            |
| Inhaltsqualität (Quality of Content)              | ✔                                                                                                      |                                                                                                                 |
| Übersichtlichkeit (Clarity)                       | ✔                                                                                                      |                                                                                                                 |
| Antwortverhalten (Response behavior)              | ❌                                                                                                      | entfällt                                                                                                        |
| Antwortqualität (Response quality)                | ❌                                                                                                      | entfällt                                                                                                        |
| Verständnis (Comprehensibility)                   | ❌                                                                                                      | entfällt                                                                                                        |

## Notes

* Interview Nr. 92 should be removed